Description Usage Arguments See Also
View source: R/dashboard-metrics.R
Refers to the ratio of permission resident participants to the state population.
1 | calc_part_rate(part, pop_county, rate_test, res_type)
|
part |
named list holding resident participant summary for privilege |
pop_county |
data frame: population table for state |
rate_test |
test values to pass to est_rate() |
res_type |
identifies residency specific permissions ("Resident", "Nonresident", NULL) |
Other dashboard functions:
calc_metrics(),
calc_part(),
calc_priv_rate(),
est_month(),
est_pop(),
est_rate(),
fill_missing_months(),
format_metrics(),
write_dash()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.