Description Usage Arguments See Also
Not sure why the sales table would contain missing customer IDs, but there are usually a handfull of NAs.
1 | drop_na_custid(sale)
|
sale |
data frame: sale table |
Other functions for producing license history:
data_check_sa(),
load_license(),
remove_table(),
write_history()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.