Description Usage Arguments See Also
This is used as a generic function in plot_value2. It was
copied from dashboard-template code shared with state agencies. Included
in entirety here to reduce dependencies.
1 |
df |
data frame with summary results |
plot_title |
caption to show in plot |
measure |
variable to be plotted on the y axis |
Other functions to run dashboard visualization:
get_county_map(),
int_breaks(),
join_county_map(),
plot_county(),
plot_month(),
plot_value2(),
plotly_config(),
run_visual_county(),
ui_button_layout()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.