Description Usage Arguments See Also Examples
Mostly a wrapper for plot_bar with some
additional formatting. It's expected that the input table will only contain
a single group-quarter-segment.
1 | plot_value2(df, plot_title = "", measure = "value", n = 5)
|
df |
data frame with summary results |
plot_title |
caption to show in plot |
measure |
variable to be plotted on the y axis |
n |
passed to |
Other functions to run dashboard visualization:
get_county_map(),
int_breaks(),
join_county_map(),
plot_bar(),
plot_county(),
plot_month(),
plotly_config(),
run_visual_county(),
ui_button_layout()
1 2 3 4 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.