Description Preparing License History Preparing Dashboard Metrics
This includes a summary of the core functions grouped by task.
use load_license to pull standardized license data
from sqlite
use data_check_sa to check formatting rules of
standardized data
use drop_na_custid to remove any records with a missing
customer ID from the sale table
use functions from salic (rank_sale, make_history)
to build license history
finally use write_history to write to sqlite
use load_sqlite functions to pull in state-level
customer, sales, and census population data
use load_history and recode_history to
prepare data for a specific permission
use quarterly_filter, quarterly_lapse,
and calc_metrics in sequence to produce a list that stores
all metrics for a permission
use format_metrics and write_dash
in sequence to produce csv files by permission-quarter
use run_visual to check results
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.