Description Usage Arguments See Also
Ensure county_fips isn't populated where res == 0 or is.na(res). There are typically a few of these and we don't want them showing up in the data dive.
1 |
x |
license history with county_fips & res variables |
Other data dive functions:
drop_state_code(),
filter_demo(),
get_county_map_dive(),
load_cust_samp(),
plot_county_dive(),
plot_dist(),
plot_trend(),
run_visual_dive(),
set_other_county_na(),
summarize_trend()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.